@@ -10,8 +10,8 @@ from dependency_injector.wiring import inject, Provide
 from pydantic import BaseSettings
 
 from web_foundation.kernel.dispatcher import IDispatcher
-from web_foundation.app.resources.cache.cache import AppCache
-from web_foundation.app.resources.cache.memory import InMemoryCache
+from web_foundation.app.resources.cache.repo import AppStore
+from web_foundation.app.resources.cache.memory import InMemoryDictStore
 from web_foundation.app.service import Service
 from web_foundation.kernel.logger import setup_loggers, LoggerSettings
 from web_foundation.workers.worker import GenWorker
@@ -37,9 +37,14 @@ class App(Generic[AppConfig, GenWorker]):
 
     @inject
     async def _before_app_run(self, app_container: AppContainer = Provide["<container>"]):
-        await app_container.init_resources()
+        init_coro = app_container.init_resources()
+        if init_coro:
+            await init_coro
         await self.before_app_run(app_container)
-        await app_container.shutdown_resources()
+
+        shutdown_coro = app_container.shutdown_resources()
+        if shutdown_coro:
+            await shutdown_coro
 
     async def before_app_run(self, container):
         pass
@@ -109,7 +114,7 @@ class AppContainer(containers.DeclarativeContainer):
     debug = True
     app_config = providers.Configuration()
     app = providers.Dependency(instance_of=App, default=providers.Singleton(App, config=app_config, debug=debug))
-    cache = providers.Dependency(instance_of=AppCache, default=providers.Singleton(InMemoryCache))
+
     """
     Please pass here your database or any another resource in nested container
     """
