@@ -7,12 +7,15 @@ import socket
 from functools import partial
 from typing import List, Callable, Any, Type
 
+import loguru
 from dependency_injector import providers
 from pydantic import BaseModel as PDModel
 from sanic import Sanic
 from sanic.server.socket import bind_socket
 
 from web_foundation.app.app import AppContainer
+from web_foundation.app.events.store import StoreUpdateEvent
+from web_foundation.app.infrastructure.plugins.manager import PluginsManager
 from web_foundation.kernel import GenericIMessage, IMessage
 from web_foundation.workers.io.http.ext_error_handler import ExtendedErrorHandler
 from web_foundation.workers.io.http.routers.ext_router import ExtRouter
@@ -31,12 +34,14 @@ class HttpServer(Worker):
     sanic_app: Sanic
     router: ExtRouter | None
     rt_connections: List[RtConnection]
+    plugin_manager: PluginsManager | None
 
     def __init__(self, config: providers.Configuration, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.config = config
 
-    def _configure(self, sock: socket.socket = None, ext_router: ExtRouter = None):  # type: ignore
+    def _configure(self, sock: socket.socket = None, ext_router: ExtRouter = None,
+                   plugin_manager: PluginsManager = None):  # type: ignore
         self.sock = sock if sock else self.create_socket(self.config.get("host"), self.config.get("port"))
         self.router = copy.deepcopy(ext_router)
         self.sanic_app = Sanic(self.name, router=self.router)
@@ -46,6 +51,7 @@ class HttpServer(Worker):
         self.sanic_app.ctx.channel = self.channel
         self.rt_connections = []
         self._set_sanic_confs()
+        self.plugin_manager = plugin_manager
         if self.router and issubclass(self.router.__class__, ExtRouter):
             self.router.apply_routes(self.sanic_app)
 
@@ -54,9 +60,13 @@ class HttpServer(Worker):
             "docExpansion": 'none'
         }
 
+    async def _init_wrk(self, app):
+        await self._init_resources()
+        if self.plugin_manager:
+            await self.plugin_manager.init_all_plugins()
+
     async def _run(self):
-        # await self._init_resources()
-        self.sanic_app.register_listener(self._init_resources, "before_server_start")
+        self.sanic_app.register_listener(self._init_wrk, "before_server_start")
         # noinspection PyAsyncCall
         self.sanic_app.add_task(self.channel.listen_consume())
 
@@ -108,10 +118,13 @@ class HttpServer(Worker):
         await conn.freeze_request(_on_rt_close)
 
 
-def create_io_workers(config: providers.Configuration,
+def create_io_workers(server_cls: Type[HttpServer],
+                      config: providers.Configuration,
                       router: ExtRouter,
+                      plugin_manager: PluginsManager = None,
                       workers_num: int = 1,
                       fast: bool = False,
+                      **kwargs
                       ) -> List[HttpServer]:
     """
     RESERVE 0 WORKER TO CREATE FRONT SERVICE SERVING
@@ -128,8 +141,9 @@ def create_io_workers(config: providers.Configuration,
         except AttributeError:  # no cov
             w_num = os.cpu_count() or 1
     for i in range(w_num):
-        worker = HttpServer(config)
-        worker.configure(f"web_worker_{i + 1}", ext_router=router, sock=sock)
+        worker = server_cls(config)
+        worker.configure(f"web_worker_{i + 1}", ext_router=router, sock=sock,
+                         plugin_manager=plugin_manager, **kwargs)
         workers.append(worker)
     return workers
 
@@ -139,5 +153,6 @@ def subscribe_worker_rt_callback(*workers: HttpServer,
                                  callback: RtEventCallback,
                                  use_nested_classes: bool = False):
     for worker in workers:
+        worker.channel.add_event_listener(StoreUpdateEvent, worker.on_store_update)
         worker.channel.add_event_listener(event_type, partial(worker.on_event, resolve_callback=callback),
                                           use_nested_classes=use_nested_classes)
