@@ -2,9 +2,11 @@ from __future__ import annotations
 
 from typing import TypeVar
 
+import loguru
 from dependency_injector import containers
 from dependency_injector.wiring import inject, Provide
 
+from web_foundation.app.events.store import StoreUpdateEvent
 from web_foundation.kernel import Isolate
 
 
@@ -20,7 +22,9 @@ class Worker(Isolate):
 
     @inject
     async def _init_resources(self, app=None, app_container=Provide["<container>"]):
-        await app_container.init_resources()
+        init_coro = app_container.init_resources()
+        if init_coro:
+            await init_coro
         for service in app_container.app().services.values():
             service.worker = self
         pass
@@ -30,6 +34,10 @@ class Worker(Isolate):
         self._configure(*args, **kwargs)
         self._configured = True
 
+    @inject
+    async def on_store_update(self, event: StoreUpdateEvent, app_container=Provide["<container>"]):
+        await app_container.store().set_item(event.key, event.value)
+
     def _configure(self, *args, **kwargs):
         pass
 
